clients.lxxl.api
=========================


.. image:: https://secure.travis-ci.org/Education-Numerique/api.png
        :target: http://travis-ci.org/Education-Numerique/api

Api services for lxxl.

You need to install puke in order to build (https://github.com/webitup/puke).

Edit the yak file to fit your mileage, then puke.